@@ -3,22 +3,24 @@
 """ version.py
 Version is an abstract class which versions of different types can be defined from.
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "0.3.0"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Prototype"
+# Package Header #
+from .__header__ import *
 
-# Default Libraries #
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
+
+
+# Imports #
+# Standard Libraries #
 from abc import abstractmethod
 
-# Downloaded Libraries #
+# Third-Party Packages #
 from baseobjects import BaseObject
 
-# Local Libraries #
+# Local Packages #
 from .versiontype import VersionType
 
 
@@ -83,6 +85,15 @@ class Version(BaseObject):
         if init:
             self.construct(obj=obj, ver_name=ver_name)
 
+    # Representation
+    def __hash__(self):
+        """Overrides hash to make the object hashable.
+
+        Returns:
+            The system ID of the object.
+        """
+        return id(self)
+
     # Type Conversion
     @abstractmethod
     def __str__(self):
