@@ -4,21 +4,23 @@
 A dataclass like object that contains a str name and associated class for a version. See versions for examples of
 implementation.
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "0.3.0"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Prototype"
+# Package Header #
+from .__header__ import *
 
-# Default Libraries #
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
 
-# Downloaded Libraries #
+
+# Imports #
+# Standard Libraries #
+
+# Third-Party Packages #
 from baseobjects import BaseObject
 
-# Local Libraries #
+# Local Packages #
 
 
 # Definitions #
@@ -44,6 +46,15 @@ class VersionType(BaseObject):
         if init:
             self.construct(name=name, class_=class_)
 
+    # Representation
+    def __hash__(self):
+        """Overrides hash to make the object hashable.
+
+        Returns:
+            The system ID of the object.
+        """
+        return id(self)
+
     # Type Conversion
     def __str__(self):
         """Returns the str representation of the version.
